@@ -70,6 +70,14 @@
 //! - **no scripts needed**, `cargo build` + `cargo test` **can produce and test** (if lang installed) generated bindings
 //!
 //!
+//! Gated behind **feature flags**, these enable:
+//!
+//! - `derive` - Proc macros such as `ffi_constant`, `ffi_function`, `ffi_type`.
+//! - `testing` - Functions to test generated Python, C#, C from Unit tests.
+//! - `serde` - Serde attributes on internal types.
+//! - `log` - Invoke `log` on FFI errors (you still need actual logger).
+//!
+//!
 //! ## Supported Rust Constructs
 //! See the [**reference project**](https://github.com/ralfbiedert/interoptopus/tree/master/interoptopus_reference_project/src); it lists all supported constructs including:
 //! - [functions](https://github.com/ralfbiedert/interoptopus/blob/master/interoptopus_reference_project/src/functions.rs) (`extern "C"` functions and delegates)
@@ -201,8 +209,6 @@ pub mod lang {
 /// You can then use `my_inventory_function`, which will return a [`Library`], in a backend to
 /// produce bindings to your language.
 ///
-#[cfg(feature = "derive")]
-#[cfg_attr(docsrs, doc(cfg(feature = "derive")))] // does this work?
 #[macro_export]
 macro_rules! inventory {
     (
